16.9. cdist-type__apt_source(7) — cdist 6.9.4 documentation

# 16.9. cdist-type__apt_source(7)

## 16.9.1. NAME

cdist-type__apt_source - Manage apt sources

## 16.9.2. DESCRIPTION

This cdist type allows you to manage apt sources. It invokes index update internally when needed so call of index updating type is not needed.

## 16.9.3. REQUIRED PARAMETERS

uri

  the uri to the apt repository

## 16.9.4. OPTIONAL PARAMETERS

arch

  set this if you need to force and specific arch (ubuntu specific)

state

  'present' or 'absent', defaults to 'present'

distribution

  the distribution codename to use. Defaults to DISTRIB_CODENAME from the targets /etc/lsb-release

component

  space delimited list of components to enable. Defaults to an empty string.

## 16.9.5. BOOLEAN PARAMETERS

include-src

  include deb-src entries

## 16.9.6. EXAMPLES

    __apt_source rabbitmq \
       --uri http://www.rabbitmq.com/debian/ \
       --distribution testing \
       --component main \
       --include-src \
       --state present

    __apt_source canonical_partner \
       --uri http://archive.canonical.com/ \
       --component partner --state present

## 16.9.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.9.8. COPYING

Copyright (C) 2011-2018 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.